<?php
/**
 * @copyright	Copyright (c) 2016 AmyTheme (http://www.amytheme.com). All rights reserved.
 * @license		http://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 */

defined('ABSPATH') or die;

// ===============================================================================================
// -----------------------------------------------------------------------------------------------
// FRAMEWORK SETTINGS
// -----------------------------------------------------------------------------------------------
// ===============================================================================================
$theme	= wp_get_theme();

$settings	= array(
	'menu_title'		=> esc_html__('Amy Movie', 'amy-movie'),
	'menu_type'			=> 'menu',
	'menu_slug'			=> 'amy-movie',
	'menu_icon'			=> get_template_directory_uri() . '/images/config/icon_setting.png',
	'framework_title'	=> sprintf(esc_html__('Amy Movie Theme v%1$s Configuration', 'amy-movie'), $theme->get('Version')),
	'ajax_save'			=> false,
	'show_reset_all'	=> false,
);

// ===============================================================================================
// -----------------------------------------------------------------------------------------------
// FRAMEWORK OPTIONS
// -----------------------------------------------------------------------------------------------
// ===============================================================================================
$options		= array();

// ---------------------------------------------------------
// TOP BAR
// ---------------------------------------------------------
$menus 			= wp_get_nav_menus();
$menu_fields 	= array();

if (!empty($menus)) {
	foreach ($menus as $menu) {
		$menu_fields[ $menu->slug ] = $menu->name;
	}
}

$top_bar_fields	= array(
	array(
		'id'				=> 'module',
		'type'				=> 'select',
		'class'				=> 'chosen',
		'title'				=> esc_html__('Module Type', 'amy-movie'),
		'default_option'	=> esc_html__('Choose a Module', 'amy-movie'),
		'options'			=> array(
			'text'		=> esc_html__('Text', 'amy-movie'),
			'link'		=> esc_html__('Link', 'amy-movie'),
			'social'	=> esc_html__('Social List', 'amy-movie'),
			'login'		=> esc_html__('WP Login', 'amy-movie'),
			'menu'		=> esc_html__('Menu', 'amy-movie'),
		),
	),

	array(
		'id'				=> 'icon',
		'type'				=> 'icon',
		'title'				=> esc_html__('Icon', 'amy-movie'),
		'dependency'		=> array('module', 'any', 'text,link'),
	),

	array(
		'id'				=> 'text',
		'type'				=> 'text',
		'title'				=> esc_html__('Text', 'amy-movie'),
		'multilang'			=> true,
		'dependency'		=> array('module', 'any', 'text,link'),
	),

	array(
		'id'				=> 'm_color',
		'type'				=> 'color_picker',
		'title'				=> esc_html__('Color', 'amy-movie'),
		'dependency'		=> array('module', 'any', 'text,link'),
	),

	array(
		'id'				=> 'm_bg_color',
		'type'				=> 'color_picker',
		'title'				=> esc_html__('Background Color', 'amy-movie'),
		'dependency'		=> array('module', 'any', 'text,link'),
	),

	array(
		'id'				=> 'link',
		'type'				=> 'text',
		'title'				=> esc_html__('Link URL', 'amy-movie'),
		'multilang'			=> true,
		'attributes'		=> array(
			'placeholder'		=> 'http://',
		),
		'dependency'		=> array('module', '==', 'link'),
	),

	array(
		'id'				=> 'target',
		'type'				=> 'select',
		'title'				=> esc_html__('Link Target', 'amy-movie'),
		'class'				=> 'chosen',
		'options'			=> array(
			''			=> '_self',
			'_blank'	=> '_blank',
		),
		'dependency'		=> array('module', '==', 'link'),
	),

	array(
		'id'				=> 'menu_slug',
		'type'				=> 'select',
		'class'				=> 'chosen',
		'title'				=> esc_html__('Chosen menu', 'amy-movie'),
		'options'			=> $menu_fields,
		'dependency'		=> array('module', '==', 'menu'),
	),

	array(
		'id'				=> 'class',
		'type'				=> 'text',
		'title'				=> esc_html__('CSS Class', 'amy-movie'),
		'multilang'			=> true,
		'dependency'		=> array('module', '!=', ''),
	),
	array(
		'id'				=> 'visible_type',
		'type'				=> 'select',
		'class'				=> 'chosen',
		'title'				=> esc_html__('Visible to', 'amy-movie'),
		'options'			=> array(
			'any'		=> esc_html__('Everyone', 'amy-movie'),
			'user'		=> esc_html__('User Only', 'amy-movie'),
			'guest'		=> esc_html__('Guest Only', 'amy-movie'),
		),
		'dependency'		=> array('module', '!=', ''),
	),
);


$options[]	= array(
	'name'		=> 'top_bar',
	'title'		=> esc_html__('Top Bar', 'amy-movie'),
	'icon'		=> 'fa fa-bars',
	'fields'	=> array(
		array(
			'id'			=> 'top_bar',
			'type'			=> 'switcher',
			'title'			=> esc_html__('Enable Top Bar', 'amy-movie'),
			'default'		=> 1,
		),

		array(
			'id'				=> 'top_bar_left',
			'type'				=> 'group',
			'title'				=> esc_html__('Top Bar Left', 'amy-movie'),
			'button_title'		=> esc_html__('Add New Module', 'amy-movie'),
			'accordion_title'	=> esc_html__('New Module', 'amy-movie'),
			'dependency'		=> array('top_bar', '==', 1),
			'fields'			=> $top_bar_fields,
		),
		array(
			'id'				=> 'top_bar_right',
			'type'				=> 'group',
			'title'				=> esc_html__('Top Bar Right', 'amy-movie'),
			'button_title'		=> esc_html__('Add New Module', 'amy-movie'),
			'accordion_title'	=> esc_html__('New Module', 'amy-movie'),
			'dependency'		=> array('top_bar', '==', 1),
			'fields'			=> $top_bar_fields,
		),
	),
);

// ---------------------------------------------------------
// HEADER
// ---------------------------------------------------------
$options[]	= array(
	'name'		=> 'header',
	'title'		=> esc_html__('Header', 'amy-movie'),
	'icon'		=> 'fa fa-list-alt',
	'sections'	=> array(
		array(
			'name'		=> 'header_logo_options',
			'title'		=> esc_html__('Logo', 'amy-movie'),
			'fields'	=> array(
				array(
					'id'	=> 'favicon',
					'type'	=> 'image',
					'title'	=> esc_html__('Favicon', 'amy-movie'),
				),

				array(
					'id'		=> 'logo_text',
					'type'		=> 'text',
					'default'	=> get_bloginfo('name'),
					'title'		=> esc_html__('Site Logo Text', 'amy-movie'),
					'info'		=> esc_html__('This is optional if you upload any logo, this is will disable...', 'amy-movie'),
				),

				array(
					'id'	=> 'logo',
					'type'	=> 'image',
					'title'	=> esc_html__('Site Logo', 'amy-movie'),
				),

				array(
					'id'	=> 'logo2x',
					'type'	=> 'image',
					'title'	=> esc_html__('Site Logo @2x for Retina', 'amy-movie'),
				),

				array(
					'id'	=> 'logo_padding_top',
					'type'	=> 'number',
					'title'	=> esc_html__('Logo Padding Top', 'amy-movie'),
					'after'	=> '<em>px</em>',
				),

				array(
					'id'	=> 'logo_padding_bottom',
					'type'	=> 'number',
					'title'	=> esc_html__('Logo Padding Bottom', 'amy-movie'),
					'after'	=> '<em>px</em>',
				),
			),
		),

		array(
			'name'		=> 'header_layout_options',
			'title'		=> esc_html__('Header Layout', 'amy-movie'),
			'fields'	=> array(
				array(
					'id'		=> 'header_style',
					'type'		=> 'image_select',
					'title'		=> esc_html__('Header Style', 'amy-movie'),
					'options'	=> array(
						'default'				=> get_template_directory_uri() . '/images/config/header/header-style-default.png',
						'left'					=> get_template_directory_uri() . '/images/config/header/header-style-left.png',
						'center'				=> get_template_directory_uri() . '/images/config/header/header-style-center.png',
						//'inline'				=> get_template_directory_uri() . '/images/config/header/header-inline.png',
						//'classic'				=> get_template_directory_uri() . '/images/config/header/header-classic.png',
						//'compact-transparent'	=> get_template_directory_uri() . '/images/config/header/header-compact.png',
					),
					'attributes'			=> array(
						'data-depend-id'	=> 'header_style',
					),
					'radio'		=> true,
					'default'	=> 'default',
				),

				array(
					'id'		=> 'header_skin',
					'type'		=> 'select',
					'class'		=> 'chosen',
					'title'		=> esc_html__('Header Skin', 'amy-movie'),
					'options'	=> array(
						'light'		=> esc_html__('Light', 'amy-movie'),
						'dark'		=> esc_html__('Dark', 'amy-movie'),
					),
					'default'		=> 'light',
					'dependency'	=> array('header_style', '==', 'default'),
				),

				array(
					'id'		=> 'line_through_position',
					'type'		=> 'select',
					'class'		=> 'chosen',
					'title'		=> esc_html__('Line Through Position', 'amy-movie'),
					'options'	=> array(
						'bottom'	=> esc_html__('Bottom', 'amy-movie'),
						'default'	=> esc_html__('Center', 'amy-movie'),
						'none'		=> esc_html__('None', 'amy-movie')
					),
					'desc'		=> esc_html__('Line through position when menu hover', 'amy-movie'),
					'default'	=> 'default',
					'dependency'	=> array('header_skin', '!=', 'dark'),
				),

				array(
					'id'		=> 'dark_module_login',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Show module login', 'amy-movie'),
					'default'	=> false,
					'dependency'	=> array('header_style|header_skin', '==|==', 'default|dark'),
				),

				array(
					'id'		=> 'show_search',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Show search on header', 'amy-movie'),
					'dependency'	=> array('header_style', '==', 'default'),
					'default'	=> false,
				),

				array(
					'id'		=> 'menu_max_width',
					'type'		=> 'number',
					'title'		=> esc_html__('Disable menu in max-width', 'amy-movie'),
					'default'	=> '992',
					'label'		=> esc_html__('you can set it eg. 1200, 992, 768 or any width etc..', 'amy-movie'),
				),
			)
		)
	),
);

// ----------------------------------------------
// FOOTER
// ----------------------------------------------
$options[]	= array(
	'name'		=> 'footer',
	'title'		=> esc_html__('Footer', 'amy-movie'),
	'icon'		=> 'fa fa-list-alt',
	'fields'	=> array(
		array(
			'id'		=> 'enable_footer',
			'type'		=> 'switcher',
			'title'		=> esc_html__('Enable Footer', 'amy-movie'),
			'label'		=> esc_html__('Enable footer widgets area in all pages.', 'amy-movie'),
			'default'	=> true,
		),

		array(
			'id'			=> 'footer_bg',
			'type'			=> 'image',
			'title'			=> esc_html__('Footer Background Image', 'amy-movie'),
		),

		array(
			'id'			=> 'footer_bg_color',
			'type'			=> 'color_picker',
			'title'			=> esc_html__('Footer Background Color', 'amy-movie'),
		),

		array(
			'id'		=> 'footer_widgets_before',
			'type'		=> 'switcher',
			'title'		=> esc_html__('Footer Widgets Before', 'amy-movie'),
			'label'		=> esc_html__('A full-width widget before footer widgets', 'amy-movie'),
			'default'	=> false,
		),

		array(
			'id'		=> 'footer_widgets',
			'type'		=> 'image_select',
			'title'		=> esc_html__('Footer Widgets', 'amy-movie'),
			'options'	=> array(
				'1'			=> get_template_directory_uri() . '/images/config/footer-widget-1.png',
				'2'			=> get_template_directory_uri() . '/images/config/footer-widget-2.png',
				'3'			=> get_template_directory_uri() . '/images/config/footer-widget-3.png',
				'4'			=> get_template_directory_uri() . '/images/config/footer-widget-4.png',
				'5'			=> get_template_directory_uri() . '/images/config/footer-widget-5.png',
				'6'			=> get_template_directory_uri() . '/images/config/footer-widget-6.png',
				'7'			=> get_template_directory_uri() . '/images/config/footer-widget-7.png',
				'8'			=> get_template_directory_uri() . '/images/config/footer-widget-8.png',
				'9'			=> get_template_directory_uri() . '/images/config/footer-widget-9.png',
				'10'		=> get_template_directory_uri() . '/images/config/footer-widget-10.png',
			),
			'radio'		=> true,
			'default'	=> '4',
		),

		array(
			'id'		=> 'footer_widgets_after',
			'type'		=> 'switcher',
			'title'		=> esc_html__('Footer Widgets After', 'amy-movie'),
			'label'		=> esc_html__('A full-width widget after footer widgets', 'amy-movie'),
			'default'	=> false,
		),

		array(
			'id'		=> 'enable_copyright',
			'type'		=> 'switcher',
			'title'		=> esc_html__('Enable Copyright', 'amy-movie'),
			'label'		=> esc_html__('Enable copyright on all pages.', 'amy-movie'),
			'default'	=> true,
		),

		array(
			'id'				=> 'copyright_left',
			'type'				=> 'group',
			'title'				=> esc_html__('Copyright Left', 'amy-movie'),
			'button_title'		=> esc_html__('Add New Module', 'amy-movie'),
			'accordion_title'	=> esc_html__('New Module', 'amy-movie'),
			'dependency'		=> array('enable_copyright', '==', 1),
			'fields'			=> $top_bar_fields,
		),

		array(
			'id'				=> 'copyright_right',
			'type'				=> 'group',
			'title'				=> esc_html__('Copyright Right', 'amy-movie'),
			'button_title'		=> esc_html__('Add New Module', 'amy-movie'),
			'accordion_title'	=> esc_html__('New Module', 'amy-movie'),
			'dependency'		=> array('enable_copyright', '==', 1),
			'fields'			=> $top_bar_fields,
		),
	),
);

// ----------------------------------------------
// MOVIE
// ----------------------------------------------
$list_fields_visible = array(
	'movie_release' 	=> esc_html__('Release', 'amy-movie'),
	'movie_imdb' 		=> esc_html__('Imdb', 'amy-movie'),
	'movie_language' 	=> esc_html__('Language', 'amy-movie'),
	'movie_genre' 		=> esc_html__('Genre', 'amy-movie'),
	'movie_actor' 		=> esc_html__('Actor', 'amy-movie'),
	'movie_director' 	=> esc_html__('Director', 'amy-movie'),
	'movie_cinema' 		=> esc_html__('Cinema', 'amy-movie')
);

$custom_fields			= amy_get_option('movie_custom_fields');

if (!empty($custom_fields)) {
	foreach ($custom_fields as $field) {
		if ($field['type'] == 'category' || $field['type'] == 'person') {
			$name = (isset($field['name']) && $field['name'] != '') ? $field['name'] : '';
			$singular_name = (isset($field['singular_name']) && $field['singular_name'] != '') ? sanitize_title($field['singular_name']) : sanitize_title($name);

			$list_fields_visible[$singular_name] = $name;
		}
	}
}

$options[]	= array(
	'name'		=> 'movie',
	'title'		=> esc_html__('Movie', 'amy-movie'),
	'icon'		=> 'fa fa-film',
	'sections'	=> array(
		array(
			'name'		=> 'movie_general',
			'title'		=> esc_html__('General', 'amy-movie'),
			'fields'	=> array(
				array(
					'id'		=> 'movie_heading_cinema',
					'type'		=> 'heading',
					'content'	=> esc_html__('Cinema System', 'amy-movie'),
				),

				array(
					'id'		=> 'enable_m_cinema',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Enable Cinema System', 'amy-movie'),
					'default'	=> true,
					'label'		=> esc_html__('If disable all featured interest cinema will disable', 'amy-movie')
				),

				array(
					'id'		=> 'is_single_cinema',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Is Single Cinema', 'amy-movie'),
					'default'	=> false,
					'dependency'	=> array('enable_m_cinema', '==', '1')
				),

				array(
					'id'		=> 'single_cinema_detail',
					'type'		=> 'fieldset',
					'title'		=> esc_html__('Single Cinema Detail', 'amy-movie'),
					'dependency'	=> array('enable_m_cinema|is_single_cinema', '==|==', '1|1'),
					'fields'		=> array(
						array(
							'id'	=> 'title',
							'type'	=> 'text',
							'title'	=> esc_html__('Title', 'amy-movie')
						),

						array(
							'id'    => 'banner',
							'type'  => 'image',
							'title' => esc_html__('Banner', 'amy-movie'),
						),

						array(
							'id'    => 'gallery',
							'type'  => 'gallery',
							'title' => esc_html__('Gallery', 'amy-movie'),
						),

						array(
							'id'    => 'address',
							'type'  => 'text',
							'title' => esc_html__('Address', 'amy-movie'),
						),

						array(
							'id'    => 'phone',
							'type'  => 'text',
							'title' => esc_html__('Phone', 'amy-movie'),
						),

						array(
							'id'    => 'website',
							'type'  => 'text',
							'title' => esc_html__('Website', 'amy-movie'),
						),

						array(
							'id'    => 'email',
							'type'  => 'text',
							'title' => esc_html__('Email', 'amy-movie'),
						),

						array(
							'id'    	=> 'map',
							'type'  	=> 'textarea',
							'title' 	=> esc_html__('Google Map Iframe', 'amy-movie'),
							'sanitize' 	=> true,
							'after'		=> esc_html__('Visit Google maps to create your map (Step by step: 1) Find location 2) Click the cog symbol in the lower right corner and select "Share or embed map" 3) On modal window select "Embed map" 4) Copy iframe code and paste it).', 'amy-movie'),
						),
					)
				),

				array(
					'id'		=> 'enable_m_ticket',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Enable Book Ticket System', 'amy-movie'),
					'default'	=> false,
					'dependency'	=> array('enable_m_cinema', '==', '1')
				),

				array(
					'id'		=> 'movie_heading_function_fields',
					'type'		=> 'heading',
					'content'	=> esc_html__('Functions', 'amy-movie'),
				),

				array(
					'id'		=> 'enable_start_end_date',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Enable Start & End Date', 'amy-movie'),
					'default'	=> false,
				),

				array(
					'id'		=> 'enable_streaming',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Enable Streaming System', 'amy-movie'),
					'default'	=> false,
				),

				array(
					'id'		=> 'single_movie_default_layout',
					'type'		=> 'select',
					'class'		=> 'chosen',
					'title'		=> esc_html__('Single Movie Default Layout', 'amy-movie'),
					'options'	=> array(
						'normal'	=> esc_html__('Normal', 'amy-movie'),
						'stream'	=> esc_html__('Streaming', 'amy-movie'),
					),
					'dependency'	=> array('enable_streaming', '==', '1'),
					'deufalt'	=> 'stream'
				),

				/*
				array(
					'id'		=> 'enable_m_rating',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Enable System Rate', 'amy-movie'),
					'default'	=> true,
				),
				*/

				array(
					'id'		=> 'movie_heading_default_fields',
					'type'		=> 'heading',
					'content'	=> esc_html__('Default Fields', 'amy-movie'),
				),

				array(
					'id'		=> 'movie_default_fields',
					'type'		=> 'select',
					'class'		=> 'chosen',
					'title'		=> esc_html__('Enable Default Fields', 'amy-movie'),
					'options'	=> array(
						'movie_release'		=> esc_html__('Release Date', 'amy-movie'),
						'movie_duration'	=> esc_html__('Duration', 'amy-movie'),
						'movie_imdb'		=> esc_html__('IMDB', 'amy-movie'),
						'movie_mpaa'		=> esc_html__('MPAA', 'amy-movie'),
						'movie_language'	=> esc_html__('Language', 'amy-movie'),
						'movie_genre'		=> esc_html__('Genre', 'amy-movie'),
						'movie_actor'		=> esc_html__('Actor', 'amy-movie'),
						'movie_director'	=> esc_html__('Director', 'amy-movie'),
					),
					'attributes' => array(
						'multiple' => 'multiple',
					),
					'default'	=> array('movie_release', 'movie_duration', 'movie_imdb', 'movie_mpaa', 'movie_language', 'movie_genre', 'movie_actor', 'movie_director')
				),

				array(
					'id'		=> 'movie_heading_custom_fields',
					'type'		=> 'heading',
					'content'	=> esc_html__('Custom Fields', 'amy-movie')
				),

				array(
					'id'				=> 'movie_custom_fields',
					'type'				=> 'group',
					'button_title'		=> esc_html__('Add New Field', 'amy-movie'),
					'accordion_title'	=> esc_html__('New Field', 'amy-movie'),
					'fields'			=> array(
						array(
							'id'			=> 'name',
							'type'			=> 'text',
							'title'			=> esc_html__('Field Name', 'amy-movie'),
						),
						array(
							'id'			=> 'type',
							'type'			=> 'select',
							'class'			=> 'chosen',
							'title'			=> esc_html__('Type', 'amy-movie'),
							'options'		=> array(
								'text'			=> esc_html__('Text', 'amy-movie'),
								'date'			=> esc_html__('Date', 'amy-movie'),
								'category'		=> esc_html__('Category', 'amy-movie'),
								'person'		=> esc_html__('Person', 'amy-movie'),
							)
						),
						array(
							'id'			=> 'singular_name',
							'type'			=> 'text',
							'title'			=> esc_html__('Singular Name', 'amy-movie'),
							'dependency'	=> array('type', 'any', 'category,person')
						)
					),
				)
			),
		),

		array(
			'name'		=> 'movie_sarch_template',
			'title'		=> esc_html__('Search Template', 'amy-movie'),
			'fields'	=> array(
				array(
					'id'		=> 'movie_search_heading',
					'type'		=> 'heading',
					'content'	=> esc_html__('Movie Search Page', 'amy-movie'),
				),

				array(
					'id'		=> 'search_layout',
					'type'		=> 'select',
					'class'		=> 'chosen',
					'title'		=> esc_html__('Layout', 'amy-movie'),
					'options'	=> array(
						'list'		=> esc_html__('List', 'amy-movie'),
						'grid'		=> esc_html__('Grid', 'amy-movie'),
					),
					'default'	=> 'list',
				),

				array(
					'type' 			=> 'image_select',
					'title' 		=> esc_html__('Grid Layout', 'amy-movie'),
					'id' 			=> 'search_grid_layout',
					'options' 		=> array(
						'layout1' 	=> get_template_directory_uri() . '/images/shortcode/grid_layout1.png',
						'layout2' 	=> get_template_directory_uri() . '/images/shortcode/grid_layout2.png',
						'layout3' 	=> get_template_directory_uri() . '/images/shortcode/grid_layout3.png',
						'layout4' 	=> get_template_directory_uri() . '/images/shortcode/grid_layout4.png',
					),
					'radio'		=> true,
					'attributes'			=> array(
						'data-depend-id'	=> 'search_grid_layout',
					),
					'default'		=> 'layout1',
					'dependency'	=> array('search_layout', '==', 'grid'),
				),

				array(
					'type'			=> 'select',
					'title'			=> esc_html__('Columns', 'amy-movie'),
					'id'			=> 'search_column',
					'class'			=> 'chosen',
					'options'		=> array(
						'2'	=> esc_html__('2 column', 'amy-movie'),
						'3'	=> esc_html__('3 column', 'amy-movie'),
						'4'	=> esc_html__('4 column', 'amy-movie'),
						'5' => esc_html__('5 column', 'amy-movie'),
					),
					'default'			=> '4',
					'dependency'	=> array('search_layout|search_grid_layout', '==|any', 'grid|layout1,layout3,layout4'),
				),

				array(
					'type'			=> 'select',
					'title'			=> esc_html__('Columns', 'amy-movie'),
					'id'			=> 'search_layout2_column',
					'class'			=> 'chosen',
					'options'		=> array(
						'2'	=> esc_html__('2 column', 'amy-movie'),
						'3'	=> esc_html__('3 column', 'amy-movie'),
					),
					'default'			=> '2',
					'dependency'	=> array('search_layout|search_grid_layout', '==|==', 'grid|layout2'),
				),

				array(
					'id' 			=> 'search_number',
					'type' 			=> 'text',
					'title' 		=> esc_html__('Search Per Page', 'amy-movie'),
					'info'			=> esc_html__('Movie per page in result search movie', 'amy-movie'),
					'default'		=> '8'
				),
			),
		),

		array(
			'name'		=> 'movie_category_template',
			'title'		=> esc_html__('Category Template', 'amy-movie'),
			'fields'	=> array(
				array(
					'id'		=> 'movie_genre_heading',
					'type'		=> 'heading',
					'content'	=> esc_html__('Genre & Category Page', 'amy-movie'),
				),

				array(
					'id'				=> 'genre_sidebar',
					'type'				=> 'select',
					'class'				=> 'chosen',
					'title'				=> esc_html__('Sidebar', 'amy-movie'),
					'options'			=> array(
						'right'				=> esc_html__('Right Sidebar', 'amy-movie'),
						'left'				=> esc_html__('Left Sidebar', 'amy-movie'),
						'full'				=> esc_html__('No Sidebar', 'amy-movie'),
					),
					'default'			=> 'right',
				),

				array(
					'id'				=> 'genre_widget',
					'type'				=> 'select',
					'class'				=> 'chosen',
					'title'				=> esc_html__('Sidebar Widget', 'amy-movie'),
					'options'			=> amy_movie_wp_registered_sidebars(),
					'default_option'	=> esc_html__('Select a sidebar (default primary)', 'amy-movie'),
					'dependency'		=> array('genre_sidebar', 'any', 'right,left'),
					'default'			=> 'rightbar',
				),

				array(
					'id'			=> 'movie_genre_orderby',
					'type'			=> 'select',
					'class'			=> 'chosen',
					'title'			=> esc_html__('Movie Order By', 'amy-movie'),
					'options'		=> array(
						'_amy_movie_rate'	=> esc_html__('Rate', 'amy-movie'),
						'_amy_movie_release'	=> esc_html__('Release Date', 'amy-movie'),
						'_amy_post_views_count'	=> esc_html__('Post Views', 'amy-movie'),
						'ID'					=> esc_html__('Post ID', 'amy-movie'),
						'title'					=> esc_html__('Title', 'amy-movie'),
						'date'					=> esc_html__('Date', 'amy-movie'),
						'rand'					=> esc_html__('Random Order', 'amy-movie'),
						'comment_count'			=> esc_html__('Comment Count', 'amy-movie'),
					),
					'default'		=> 'date'
				),

				array(
					'id'		=> 'genre_layout',
					'type'		=> 'select',
					'class'		=> 'chosen',
					'title'		=> esc_html__('Layout', 'amy-movie'),
					'options'	=> array(
						'list'		=> esc_html__('Shortcode Movie List', 'amy-movie'),
						'grid'		=> esc_html__('Shortcode Movie Grid', 'amy-movie'),
						'list-2'	=> esc_html__('Shortcode Movie List V2', 'amy-movie'),
						'grid-2'	=> esc_html__('Shortcode Movie Grid V2', 'amy-movie')
					),
					'default'	=> 'list',
				),

				array(
					'type' 			=> 'image_select',
					'title' 		=> esc_html__('Grid Layout', 'amy-movie'),
					'id' 			=> 'grid_layout',
					'options' 		=> array(
						'layout1' 	=> get_template_directory_uri() . '/images/shortcode/grid_layout1.png',
						'layout2' 	=> get_template_directory_uri() . '/images/shortcode/grid_layout2.png',
						'layout3' 	=> get_template_directory_uri() . '/images/shortcode/grid_layout3.png',
						'layout4' 	=> get_template_directory_uri() . '/images/shortcode/grid_layout4.png',
					),
					'radio'		=> true,
					'attributes'			=> array(
						'data-depend-id'	=> 'grid_layout',
					),
					'default'		=> 'layout1',
					'dependency'	=> array('genre_layout', '==', 'grid'),
				),

				array(
					'type' 			=> 'image_select',
					'title' 		=> esc_html__('Grid V2 Layout', 'amy-movie'),
					'id' 			=> 'grid_v2_layout',
					'options' 		=> array(
						'grid-1' 	=> get_template_directory_uri() . '/images/shortcode/grid_layout1.png',
						'grid-2' 	=> get_template_directory_uri() . '/images/shortcode/grid_layout2.png',
					),
					'radio'		=> true,
					'attributes'			=> array(
						'data-depend-id'	=> 'grid_v2_layout',
					),
					'default'		=> 'grid-1',
					'dependency'	=> array('genre_layout', '==', 'grid-2'),
				),

				array(
					'type'			=> 'select',
					'title'			=> esc_html__('Columns', 'amy-movie'),
					'id'			=> 'column',
					'class'			=> 'chosen',
					'options'		=> array(
						'2'	=> esc_html__('2 column', 'amy-movie'),
						'3'	=> esc_html__('3 column', 'amy-movie'),
						'4'	=> esc_html__('4 column', 'amy-movie'),
						'5' => esc_html__('5 column', 'amy-movie'),
					),
					'default'			=> '4',
					'dependency'	=> array('genre_layout|grid_layout', '==|any', 'grid|layout1,layout3,layout4'),
				),

				array(
					'type'		=> 'select',
					'title'		=> esc_html__('Columns', 'amy-movie'),
					'id'		=> 'layout2_column',
					'class'		=> 'chosen',
					'options'		=> array(
						'2'	=> esc_html__('2 column', 'amy-movie'),
						'3'	=> esc_html__('3 column', 'amy-movie'),
					),
					'default'			=> '2',
					'dependency'	=> array('genre_layout|grid_layout', '==|==', 'grid|layout2'),
				),

				array(
					'type'			=> 'select',
					'title'			=> esc_html__('Columns', 'amy-movie'),
					'id'			=> 'grid_v2_column',
					'class'			=> 'chosen',
					'options'		=> array(
						'2'	=> esc_html__('2 column', 'amy-movie'),
						'3'	=> esc_html__('3 column', 'amy-movie'),
						'4'	=> esc_html__('4 column', 'amy-movie'),
						'5' => esc_html__('5 column', 'amy-movie'),
						'6' => esc_html__('6 column', 'amy-movie'),
					),
					'default'			=> '4',
					'dependency'	=> array('genre_layout|grid_v2_layout', '==|==', 'grid-2|grid-1'),
				),

				array(
					'type'		=> 'select',
					'title'		=> esc_html__('Columns', 'amy-movie'),
					'id'		=> 'grid_v2_layout2_column',
					'class'		=> 'chosen',
					'options'		=> array(
						'2'	=> esc_html__('2 column', 'amy-movie'),
						'3'	=> esc_html__('3 column', 'amy-movie'),
						'4'	=> esc_html__('4 column', 'amy-movie'),
					),
					'default'			=> '2',
					'dependency'	=> array('genre_layout|grid_v2_layout', '==|==', 'grid-2|grid-2'),
				),

				array(
					'id' 			=> 'movie_number',
					'type' 			=> 'text',
					'title' 		=> esc_html__('Movies Per Page', 'amy-movie'),
					'default'		=> '10'
				),

				array(
					'type'			=> 'switcher',
					'title'			=> esc_html__('Show Pagination', 'amy-movie'),
					'id'			=> 'pagination',
					'std'			=> true,
				),
			)
		),

		array(
			'name'		=> 'movie_person_tempalte',
			'title'		=> esc_html__('Person Template', 'amy-movie'),
			'fields'	=> array(
				array(
					'id'		=> 'movie_person_heading',
					'type'		=> 'heading',
					'content'	=> esc_html__('Person Page', 'amy-movie'),
				),

				array(
					'id'				=> 'person_sidebar',
					'type'				=> 'select',
					'class'				=> 'chosen',
					'title'				=> esc_html__('Sidebar', 'amy-movie'),
					'options'			=> array(
						'right'				=> esc_html__('Right Sidebar', 'amy-movie'),
						'left'				=> esc_html__('Left Sidebar', 'amy-movie'),
						'full'				=> esc_html__('No Sidebar', 'amy-movie'),
					),
					'default'			=> 'full',
				),

				array(
					'id'				=> 'person_widget',
					'type'				=> 'select',
					'class'				=> 'chosen',
					'title'				=> esc_html__('Sidebar Widget', 'amy-movie'),
					'options'			=> amy_movie_wp_registered_sidebars(),
					'default_option'	=> esc_html__('Select a sidebar (default primary)', 'amy-movie'),
					'dependency'		=> array('person_sidebar', 'any', 'right,left'),
					'default'			=> 'rightbar',
				),

				array(
					'id'			=> 'movie_person_orderby',
					'type'			=> 'select',
					'class'			=> 'chosen',
					'title'			=> esc_html__('Movie Order By', 'amy-movie'),
					'options'		=> array(
						'_amy_movie_rate'	=> esc_html__('Rate', 'amy-movie'),
						'_amy_movie_release'	=> esc_html__('Release Date', 'amy-movie'),
						'_amy_post_views_count'	=> esc_html__('Post Views', 'amy-movie'),
						'ID'					=> esc_html__('Post ID', 'amy-movie'),
						'title'					=> esc_html__('Title', 'amy-movie'),
						'date'					=> esc_html__('Date', 'amy-movie'),
						'rand'					=> esc_html__('Random Order', 'amy-movie'),
						'comment_count'			=> esc_html__('Comment Count', 'amy-movie'),
					),
					'default'		=> 'date'
				),

				array(
					'id' 			=> 'movie_person_number',
					'type' 			=> 'text',
					'title' 		=> esc_html__('Movies Per Page', 'amy-movie'),
					'default'		=> '5'
				),
			),
		),

		array(
			'name'		=> 'movie_single',
			'title'		=> esc_html__('Single Movie', 'amy-movie'),
			'fields'	=> array(
				array(
					'id'		=> 'movie_single_heading',
					'type'		=> 'heading',
					'content'	=> esc_html__('Single Movie', 'amy-movie'),
				),

				array(
					'id'				=> 'movie_sidebar_default',
					'type'				=> 'select',
					'class'				=> 'chosen',
					'title'				=> esc_html__('Sidebar Default', 'amy-movie'),
					'options'			=> array(
						'right'				=> esc_html__('Right Sidebar', 'amy-movie'),
						'left'				=> esc_html__('Left Sidebar', 'amy-movie'),
						'full'				=> esc_html__('No Sidebar', 'amy-movie'),
					),
					'default'			=> 'right',
				),

				array(
					'id'				=> 'movie_widget_default',
					'type'				=> 'select',
					'class'				=> 'chosen',
					'title'				=> esc_html__('Movie Sidebar Widget', 'amy-movie'),
					'options'			=> amy_movie_wp_registered_sidebars(),
					'default_option'	=> esc_html__('Select a sidebar (default primary)', 'amy-movie'),
					'dependency'		=> array('movie_sidebar_default', 'any', 'right,left'),
					'default'			=> 'rightbar',
				),

				array(
					'id'				=> 'list_fields_visible',
					'type'				=> 'select',
					'title'				=> esc_html__('List Fields Visbile', 'amy-movie'),
					'options'			=> $list_fields_visible,
					'default'			=> array('movie_release, movie_imdb, movie_language, movie_genre, movie_actor, movie_director, movie_cinema'),
					'attributes' => array(
						'multiple' => 'multiple',
					),
					'class'				=> 'chosen'
				),

				array(
					'id'				=> 'single_movie_share_social',
					'type'				=> 'select',
					'title'				=> esc_html__('List Social Share', 'amy-movie'),
					'options'			=> array(
						'facebook'		=> esc_html__('Facebook', 'amy-movie'),
						'twitter'		=> esc_html__('Twitter', 'amy-movie'),
						'pinterest'		=> esc_html__('Pinterest', 'amy-movie'),
						'digg'			=> esc_html__('Digg', 'amy-movie'),
						'linkedin'		=> esc_html__('Linkedin', 'amy-movie'),
						'reddit'		=> esc_html__('Reddit', 'amy-movie'),
						'skype'			=> esc_html__('Skype', 'amy-movie'),
						'tumblr'		=> esc_html__('Tumblr', 'amy-movie'),
						'vk'			=> esc_html__('Vk', 'amy-movie'),
						'weibo'			=> esc_html__('Weibo', 'amy-movie'),
						'xing'			=> esc_html__('Xing', 'amy-movie'),
						'yahoo'			=> esc_html__('Yahoo', 'amy-movie'),
					),
					'default'			=> array('facebook', 'twitter', 'pinterest'),
					'attributes' => array(
						'multiple' => 'multiple',
					),
					'class'				=> 'chosen'
				),

				array(
					'id'		=> 'enable_movie_rating',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Enable User Rate', 'amy-movie'),
					'label'		=> esc_html__('If enable user can rate movie in page single movie', 'amy-movie'),
					'default'	=> false,
				),

				array(
					'id'		=> 'movie_comment',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Show comments in movie', 'amy-movie'),
					'default'	=> true,
				),

				array(
					'id'		=> 'movie_showtime',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Enable Showtime', 'amy-movie'),
					'default'	=> true,
					'dependency'	=> array('enable_m_cinema', '==', '1')
				),

				array(
					'id'		=> 'movie_showtime_type',
					'type'		=> 'select',
					'class'		=> 'chosen',
					'title'		=> esc_html__('Showtime type', 'amy-movie'),
					'options'		=> array(
						'all'		=> esc_html__('All Days', 'amy-movie'),
						'cm'		=> esc_html__('Coming Soon', 'amy-movie'),
					),
					'default'	=> 'full',
					'dependency'	=> array('enable_m_cinema|movie_showtime', '==|==', '1|1')
				),

				array(
					'id'		=> 'show_recent_movie',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Show Recent Movie', 'amy-movie'),
					'default'	=> false
				),

				array(
					'id'			=> 'recent_movie_type',
					'type'			=> 'select',
					'class'			=> 'chosen',
					'title'			=> esc_html__('Recent Movie', 'amy-movie'),
					'options'		=> array(
						'recent'		=> esc_html__('Recent Movie', 'amy-movie'),
						'random'		=> esc_html__('Random Movie', 'amy-movie'),
					),
					'dependency'	=> array('show_recent_movie', '==', '1'),
				),

				array(
					'id'			=> 'recent_movie_title',
					'type'			=> 'text',
					'title'			=> esc_html__('Recent Movie Title', 'amy-movie'),
					'dependency'	=> array('show_recent_movie', '==', '1'),
				),

				array(
					'id'			=> 'recent_movie_number',
					'type'			=> 'text',
					'title'			=> esc_html__( 'Recent Movie Number', 'amy-movie' ),
					'default'		=> '5',
					'dependency'	=> array( 'show_recent_movie', '==', '1' ),
				),
			)
		)
	),

);

//---------------------------------------------------------
// PAGE HEADER
//---------------------------------------------------------
$options[]	= array(
	'name'		=> 'page_header',
	'title'		=> esc_html__('Page Header', 'amy-movie'),
	'icon'		=> 'fa fa-file-o',
	'fields'	=> array(
		array(
			'id'			=> 'text_position',
			'type'			=> 'select',
			'title'			=> esc_html__('Text Position', 'amy-movie'),
			'options'		=> array(
				'center'	=> esc_html__('Center', 'amy-movie'),
				'left'		=> esc_html__('Left', 'amy-movie'),
				'right'		=> esc_html__('Right', 'amy-movie'),
			),
			'default'		=> 'center',
			'class'			=> 'chosen'
		),

		array(
			'id'		=> 'page_header_padding',
			'type'		=> 'fieldset',
			'inline'	=> true,
			'title'		=> esc_html__('Padding', 'amy-movie'),
			'fields'	=> array(
				array(
					'id'	=> 'top',
					'type'	=> 'number',
					'title'	=> esc_html__('Top', 'amy-movie'),
					'after'	=> ' px',
				),
				array(
					'id'	=> 'bottom',
					'type'	=> 'number',
					'title'	=> esc_html__('Bottom', 'amy-movie'),
					'after'	=> ' px',
				),
			),
		),
		array(
			'id'		=> 'page_header_background',
			'type'		=> 'background',
			'title'		=> esc_html__('Background', 'amy-movie'),
		),
		array(
			'id'		=> 'page_header_parallax',
			'type'		=> 'switcher',
			'title'		=> esc_html__('Parallax', 'amy-movie'),
		),
		array(
			'id'			=> 'page_header_speed',
			'type'			=> 'number',
			'title'			=> esc_html__('Parallax SpeedFactor', 'amy-movie'),
			'attributes'	=> array(
				'placeholder'	=> '0.4',
			),
			'dependency'	=> array('page_header_parallax', '==', '1'),
		),
		array(
			'id'		=> 'page_header_overlay',
			'type'		=> 'switcher',
			'title'		=> esc_html__('Overlay', 'amy-movie'),
		),
		array(
			'id'			=> 'page_header_overlay_color',
			'type'			=> 'color_picker',
			'title'			=> esc_html__('Overlay Color', 'amy-movie'),
			'dependency'	=> array('page_header_overlay', '==', '1'),
		),
		array(
			'id'		=> 'page_header_video',
			'type'		=> 'switcher',
			'title'		=> esc_html__('Video Header', 'amy-movie'),
		),
		array(
			'id'			=> 'page_header_mp4',
			'type'			=> 'upload',
			'title'			=> esc_html__('Video (mp4)', 'amy-movie'),
			'settings'		=> array(
				'upload_type'	=> 'video',
				'button_title'	=> esc_html__('Upload MP4', 'amy-movie'),
				'frame_title'	=> esc_html__('Select a video', 'amy-movie'),
				'insert_title'	=> esc_html__('Use this video', 'amy-movie'),
			),
			'dependency'	=> array('page_header_video', '==', 1),
		),
		array(
			'id'			=> 'page_header_ogv',
			'type'			=> 'upload',
			'title'			=> esc_html__('Video (ogv)', 'amy-movie'),
			'settings'		=> array(
				'upload_type'	=> 'video',
				'button_title'	=> esc_html__('Upload OGV', 'amy-movie'),
				'frame_title'	=> esc_html__('Select a video', 'amy-movie'),
				'insert_title'	=> esc_html__('Use this video', 'amy-movie'),
			),
			'dependency'	=> array('page_header_video', '==', 1),
		),
		array(
			'id'			=> 'page_header_webm',
			'type'			=> 'upload',
			'title'			=> esc_html__('Video (webm)', 'amy-movie'),
			'settings'		=> array(
				'upload_type'	=> 'video',
				'button_title'	=> esc_html__('Upload WEBM', 'amy-movie'),
				'frame_title'	=> esc_html__('Select a video', 'amy-movie'),
				'insert_title'	=> esc_html__('Use this video', 'amy-movie'),
			),
			'dependency'	=> array('page_header_video', '==', 1),
		),
		array(
			'id'			=> 'page_header_muted',
			'type'			=> 'switcher',
			'title'			=> esc_html__('Muted', 'amy-movie'),
			'default'		=> 1,
			'dependency'	=> array('page_header_video', '==', 1),
		),
		array(
			'id'			=> 'page_header_loop',
			'type'			=> 'switcher',
			'title'			=> esc_html__('Loop', 'amy-movie'),
			'dependency'	=> array('page_header_video', '==', 1),
		),
		array(
			'id'		=> 'page_header_color',
			'type'		=> 'fieldset',
			'inline'	=> true,
			'title'		=> esc_html__('Color', 'amy-movie'),
			'fields'	=> array(
				array(
					'id'	=> 'default',
					'type'	=> 'color_picker',
					'title'	=> esc_html__('Text', 'amy-movie'),
				),
				array(
					'id'	=> 'link',
					'type'	=> 'color_picker',
					'title'	=> esc_html__('Link', 'amy-movie'),
				),
				array(
					'id'	=> 'link_hover',
					'type'	=> 'color_picker',
					'title'	=> esc_html__('Link Hover', 'amy-movie'),
				),
			),
		),

		array(
			'id'		=> 'page_header_breadcrumb_color',
			'type'		=> 'fieldset',
			'inline'	=> true,
			'title'		=> esc_html__('Breadcrumb Color', 'amy-movie'),
			'fields'	=> array(
				array(
					'id'	=> 'default',
					'type'	=> 'color_picker',
					'title'	=> esc_attr__('Normal', 'amy-movie'),
				),
				array(
					'id'	=> 'hover',
					'type'	=> 'color_picker',
					'title'	=> esc_attr__('Hover', 'amy-movie'),
				),
			),
		),
	),
);

// ----------------------------------------------
// BLOG
// ----------------------------------------------
$options[]	= array(
	'name'		=> 'blog',
	'title'		=> esc_html__('Blog', 'amy-movie'),
	'icon'		=> 'fa fa-file-text',
	'fields'	=> array(
		array(
			'id'		=> 'blog_general_heading',
			'type'		=> 'heading',
			'content'	=> esc_html__('Blog', 'amy-movie'),
		),

		array(
			'id'				=> 'blog_sidebar',
			'type'				=> 'select',
			'class'				=> 'chosen',
			'title'				=> esc_html__('Blog Sidebar', 'amy-movie'),
			'options'			=> array(
				'right'				=> esc_html__('Right Sidebar', 'amy-movie'),
				'left'				=> esc_html__('Left Sidebar', 'amy-movie'),
				'full'				=> esc_html__('No Sidebar', 'amy-movie'),
			),
			'default'			=> 'right',
		),

		array(
			'id'				=> 'blog_widget',
			'type'				=> 'select',
			'class'				=> 'chosen',
			'title'				=> esc_html__('Blog Sidebar Widget', 'amy-movie'),
			'options'			=> amy_movie_wp_registered_sidebars(),
			'default_option'	=> esc_html__('Select a sidebar (default primary)', 'amy-movie'),
			'dependency'		=> array('blog_sidebar', 'any', 'right,left'),
			'default'			=> 'rightbar',
		),

		array(
			'id'		=> 'blog_layout',
			'type'		=> 'image_select',
			'title'		=> esc_html__('BLog Layout', 'amy-movie'),
			'options'	=> array(
				'list'		=> get_template_directory_uri() . '/images/shortcode/list.png',
				'grid'		=> get_template_directory_uri() . '/images/shortcode/grid.png',
				'masonry'	=> get_template_directory_uri() . '/images/shortcode/masonry.png',
			),
			'default'	=> 'list',
			'radio'		=> true,
			'attributes'			=> array(
				'data-depend-id'	=> 'blog_layout',
			),
			'info'		=> esc_html__('List, Grid or Masonry. Masonry working with No Sidebar', 'amy-movie'),
		),

				array(
			'id'		=> 'blog_column',
			'type'		=> 'select',
			'class'				=> 'chosen',
			'title'		=> esc_html__('Blog Column', 'amy-movie'),
			'options'	=> array(
				'2'		=> esc_html__('2 Columns', 'amy-movie'),
				'3'		=> esc_html__('3 Columns', 'amy-movie'),
				'4'		=> esc_html__('4 Columns', 'amy-movie'),
				'6'		=> esc_html__('6 Columns', 'amy-movie'),
				),
			'dependency'	=> array('blog_layout', '==', 'grid'),
			'default'	=> 4,
		),

		array(
			'id'		=> 'blog_img_size',
			'type'		=> 'select',
			'class'		=> 'chosen',
			'title'		=> esc_html__('Image size(optional)', 'amy-movie'),
			'options'	=> amy_movie_get_image_sizes(true, false),
			'default'	=> 'rightbar-image',
			'dependency'	=> array('blog_layout', 'any', 'list,grid'),
		),

		array(
			'id'		=> 'blog_meta_position',
			'type'		=> 'select',
			'class'		=> 'chosen',
			'title'		=> esc_html__('Content Position', 'amy-movie'),
			'class'		=> 'horizontal',
			'options'	=> array(
				'under'	=> esc_html__('Under Image', 'amy-movie'),
				'right'	=> esc_html__('Right Image', 'amy-movie'),
			),
			'default'	=> 'under',
			'dependency'	=> array('blog_layout', '==', 'list'),
		),

		array(
			'id'		=> 'blog_img_width',
			'type'		=> 'select',
			'class'		=> 'chosen',
			'title'		=> esc_html__('Image Width', 'amy-movie'),
			'options'	=> array(
				'4'		=> esc_html__('4 columns - 1/3', 'amy-movie'),
				'5'		=> esc_html__('5 columns - 5/12', 'amy-movie'),
				'6'		=> esc_html__('6 columns - 1/2', 'amy-movie'),
				'7'		=> esc_html__('7 columns - 7/12', 'amy-movie'),
			),
			'default'	=> '4',
			'dependency'	=> array('blog_meta_position|blog_layout', '==|==', 'right|list'),
		),

		array(
			'id'		=> 'blog_pagination',
			'title'		=> esc_html__('Pagination', 'amy-movie'),
			'type'		=> 'switcher',
			'default'	=> true,
			'dependency'	=> array('blog_layout', 'any', 'list,grid'),
		),

		array(
			'id'		=> 'blog_post_heading',
			'type'		=> 'heading',
			'content'	=> esc_html__('Single Post', 'amy-movie'),
		),

		array(
			'id'		=> 'post_recent',
			'type'		=> 'switcher',
			'title'		=> esc_html__('Recent Post', 'amy-movie'),
			'default'	=> true,
		),

		array(
			'id'		=> 'post_recent_by',
			'type'		=> 'select',
			'title'		=> esc_html__('Recent Post By', 'amy-movie'),
			'options'	=> array(
				'category'		=> esc_html__('Category', 'amy-movie'),
				'post_tag'		=> esc_html__('Tag', 'amy-movie'),

			),
			'default'	=> 'category',
		),

		array(
			'id'		=> 'post_recent_title',
			'type'		=> 'text',
			'title'		=> esc_html__('Recent Post title', 'amy-movie'),
			'default'	=> esc_html__('Related Article', 'amy-movie'),
		),
	),
);

//---------------------------------------------------------
// WOOCOMERCE
//---------------------------------------------------------
if (class_exists('WooCommerce')) {
	$options[] = array(
		'name' => 'woocommerce',
		'title' => esc_html__('WooCommerce', 'amy-movie'),
		'icon'	=> 'fa fa-shopping-basket',
		'fields' => array(
			array(
				'id'		=> 'woo_loop_columns',
				'type'		=> 'select',
				'title'		=> esc_html__('Shop Columns', 'amy-movie'),
				'options'	=> array(
					'2'		=> esc_html__('2 Columns', 'amy-movie'),
					'3'		=> esc_html__('3 Columns', 'amy-movie'),
					'4'		=> esc_html__('4 Columns', 'amy-movie'),
					'6'		=> esc_html__('6 Columns', 'amy-movie')
				),
				'default'	=> 4,
				'class'		=> 'chosen'
			),

			array(
				'id'               => 'woo_related_columns',
				'type'             => 'select',
				'title'            => esc_html__('Related Columns', 'amy-movie'),
				'options'	=> array(
					'2'		=> esc_html__('2 Columns', 'amy-movie'),
					'3'		=> esc_html__('3 Columns', 'amy-movie'),
					'4'		=> esc_html__('4 Columns', 'amy-movie'),
					'6'		=> esc_html__('6 Columns', 'amy-movie')
				),
				'default'	=> 4,
				'class'		=> 'chosen'
			),

			array(
				'id'               => 'woo_upsells_columns',
				'type'             => 'select',
				'title'            => esc_html__('Up-Sells Columns', 'amy-movie'),
				'options'	=> array(
					'2'		=> esc_html__('2 Columns', 'amy-movie'),
					'3'		=> esc_html__('3 Columns', 'amy-movie'),
					'4'		=> esc_html__('4 Columns', 'amy-movie'),
					'6'		=> esc_html__('6 Columns', 'amy-movie')
				),
				'default'	=> 4,
				'class'		=> 'chosen'
			),
		),
	);
}

// ----------------------------------------------
// SKIN
// ----------------------------------------------
$options[] = array(
	'name'		=> 'skin',
	'title'		=> esc_html__('Skin', 'amy-movie'),
	'icon'      => 'fa fa-paint-brush',
	'fields'	=> array(
		array(
			'id'		=> 'skin_heading_general',
			'type'		=> 'heading',
			'content'	=> esc_html__('General', 'amy-movie'),
		),

		array(
			'id'			=> 'disable_skin',
			'type'			=> 'switcher',
			'title'			=> esc_html__('Disabled Skin', 'amy-movie'),
			'label'			=> esc_html__('Using themes color', 'amy-movie'),
			'default'		=> true,
		),

		array(
			'id'		=> 'skin_color',
			'type'		=> 'select',
			'class'		=> 'chosen',
			'title'		=> esc_html__('Skin', 'amy-movie'),
			'options'	=> array(
				'red'		=> esc_html__('Red', 'amy-movie'),
				'pink'		=> esc_html__('Pink', 'amy-movie'),
				'blue'		=> esc_html__('Blue', 'amy-movie'),
				'custom'	=> esc_html__('Custom', 'amy-movie'),
			),
			'default'	=> 'red',
			'dependency'	=> array('disable_skin', '==', '0'),
		),

		array(
			'id'		=> 'skin_custom',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Custom', 'amy-movie'),
			'dependency'	=> array('skin_color|disable_skin', '==|==', 'custom|0'),
		),

		array(
			'id'		=> 'skin_heading_page_title',
			'type'		=> 'heading',
			'content'	=> esc_html__('Page title', 'amy-movie'),
		),

		array(
			'id'		=> 'pagetitle_bg_color',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Page Title Background Color', 'amy-movie'),
		),

		array(
			'id'		=> 'pagetitle_bg_img',
			'type'		=> 'image',
			'title'		=> esc_html__('Page Title Background Image', 'amy-movie'),
		),

		array(
			'id'		=> 'pagetitle_color',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Page Title Color', 'amy-movie'),
		),

		array(
			'id'		=> 'skin_heading_topbar',
			'type'		=> 'heading',
			'content'	=> esc_html__('TopBar', 'amy-movie'),
		),

		array(
			'id'		=> 'topbar_bg_color',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Topbar Background Color', 'amy-movie'),
		),

		array(
			'id'		=> 'topbar_text_color',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Topbar Text Color', 'amy-movie'),
		),

		array(
			'id'		=> 'topbar_link_color',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Topbar Link Color Color', 'amy-movie'),
		),

		array(
			'id'		=> 'topbar_link_hover_color',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Topbar Link Hover Color', 'amy-movie'),
		),

		array(
			'id'		=> 'skin_heading_header',
			'type'		=> 'heading',
			'content'	=> esc_html__('Header', 'amy-movie'),
		),

		array(
			'id'		=> 'header_bg_color',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Header Background Color', 'amy-movie')
		),

		array(
			'id'		=> 'skin_heading_menu',
			'type'		=> 'heading',
			'content'	=> esc_html__('Main Menu', 'amy-movie'),
		),

		array(
			'id'		=> 'menu_color',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Menu Color', 'amy-movie')
		),

		array(
			'id'		=> 'menu_hover_color',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Menu Hover Color', 'amy-movie')
		),

		array(
			'id'		=> 'submenu_background_color',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Submenu Background Color', 'amy-movie')
		),

		array(
			'id'		=> 'submenu_color',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Submenu Color', 'amy-movie')
		),

		array(
			'id'		=> 'submenu_hover_color',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Submenu Hover Color', 'amy-movie')
		),

		array(
			'id'		=> 'submenu_border_color',
			'type'		=> 'color_picker',
			'title'		=> esc_html__('Submenu Border Color', 'amy-movie')
		),
	),
);

// ----------------------------------------------
// TYPOGRAPHY
// ----------------------------------------------
$options[]	= array(
	'name'		=> 'typography',
	'icon'		=> 'fa fa-header',
	'title'		=> esc_html__('Typography', 'amy-movie'),
	'fields'	=> array(
		array(
			'id'				=> 'typography',
			'type'				=> 'group',
			'button_title'		=> esc_html__('Add New Typography', 'amy-movie'),
			'accordion'			=> true,
			'accordion_title'	=> esc_html__('New Typography', 'amy-movie'),
			'fields'			=> array(
				array(
					'id'			=> 'title',
					'type'			=> 'text',
					'title'			=> esc_html__('Title', 'amy-movie'),
				),
				array(
					'id'			=> 'selector',
					'type'			=> 'text',
					'title'			=> esc_html__('Selector', 'amy-movie'),
				),
				array(
					'id'			=> 'font',
					'type'			=> 'typography',
					'title'			=> esc_html__('Font Family', 'amy-movie'),
				),
				array(
					'id'			=> 'size',
					'type'			=> 'text',
					'title'			=> esc_html__('Font Size <em>(optional)</em>', 'amy-movie'),
				),
				array(
					'id'			=> 'line_height',
					'type'			=> 'text',
					'title'			=> esc_html__('Line Height <em>(optional)</em>', 'amy-movie'),
				),
				array(
					'id'			=> 'css',
					'type'			=> 'textarea',
					'title'			=> esc_html__('Custom CSS <em>(optional)</em>', 'amy-movie'),
				),
			),
			'default'		=> array(
				array(
					'title'		=> esc_html__('Body Typography', 'amy-movie'),
					'selector'	=> 'body',
					'font'		=> array(
						'family'	=> 'Roboto Condensed',
						'variant'	=> 'regular',
					),
					'size'		=> '13px',
				),
				array(
					'title'		=> esc_html__('Menu Typography', 'amy-movie'),
					'selector'	=> '#amy-site-nav .menu-item a',
					'font'		=> array(
						'family'	=> 'Roboto Condensed',
						'variant'	=> '700',
					),
					'size'		=> '15px',
				),
				array(
					'title'		=> esc_html__('SubMenu Typography', 'amy-movie'),
					'selector'	=> '#amy-site-nav .sub-menu .menu-item a',
					'font'		=> array(
						'family'	=> 'Roboto Condensed',
						'variant'	=> '700',
					),
					'size'		=> '15px',
				),
				array(
					'title'		=> esc_html__('Heading Typography', 'amy-movie'),
					'selector'	=> 'h1, h2, h3, h4, h5, h6, .h1, .h2, .h3, .h4, .h5, .h6, .amy-tab ul li a',
					'font'		=> array(
						'family'	=> 'Roboto Condensed',
						'variant'	=> '700',
					),
					'size'		=> '',
				),
				array(
					'title'		=> esc_html__('Movie Config Typography', 'amy-movie'),
					'selector'	=> '.rate, .entry-date, .pg',
					'font'		=> array(
						'family'	=> 'Roboto Condensed',
						'variant'	=> 'regular',
					),
					'size'		=> '',
				),
			),
		),

		array(
			'id'		=> 'subsets',
			'type'		=> 'select',
			'title'		=> esc_html__('Subsets', 'amy-movie'),
			'class'		=> 'chosen',
			'options'	=> array(
				'latin'			=> 'latin',
				'latin-ext'		=> 'latin-ext',
				'cyrillic'		=> 'cyrillic',
				'cyrillic-ext'	=> 'cyrillic-ext',
				'greek'			=> 'greek',
				'greek-ext'		=> 'greek-ext',
				'vietnamese'	=> 'vietnamese',
				'devanagari'	=> 'devanagari',
				'khmer'			=> 'khmer',
			),
			'attributes'	=> array(
				'data-placeholder'	=> esc_html__('Subsets', 'amy-movie'),
				'multiple'			=> 'multiple',
			),
			'default'	=> array('latin'),
		),
	),
);

// ----------------------------------------------
// SOCIAL
// ----------------------------------------------
$options[]	= array(
	'name'		=> 'social',
	'title'		=> esc_html__('Social', 'amy-movie'),
	'icon'		=> 'fa fa-share-square',
	'fields'	=> array(
		array(
			'id'				=> 'social_list',
			'type'				=> 'group',
			'title'				=> esc_html__('Social List', 'amy-movie'),
			'button_title'		=> esc_html__('Add New Social', 'amy-movie'),
			'accordion_title'	=> esc_html__('New Social', 'amy-movie'),
			'fields'			=> array(
				array(
					'id'		=> 'title',
					'type'		=> 'text',
					'title'		=> esc_html__('Title', 'amy-movie')
				),

				array(
					'id'		=> 'icon',
					'type'		=> 'icon',
					'title'		=> esc_html__('Icon', 'amy-movie')
				),

				array(
					'id'		=> 'link',
					'type'		=> 'text',
					'title'		=> esc_html__('Link', 'amy-movie')
				)
			),
			'default'		=> array(
				array(
					'icon'	=> 'fa fa-facebook',
					'title'	=> esc_html__('Facebook', 'amy-movie'),
					'link'	=> '#'
				),

				array(
					'icon'	=> 'fa fa-twitter',
					'title'	=> esc_html__('Twitter', 'amy-movie'),
					'link'	=> '#'
				),
			)
		),
	),
);

// ----------------------------------------------
// Media Options
// ----------------------------------------------
$options[] = array(
	'name'		=> 'media',
	'title'		=> esc_html__('Media', 'amy-movie'),
	'icon'      => 'fa fa-image',
	'fields'	=> array(
		array(
			'id' 				=> 'custom_image_sizes',
			'type' 				=> 'group',
			'title' 			=> esc_html__('Add Image Size', 'amy-movie'),
			'button_title' 		=> 'Add New Image Size',
			'accordion_title' 	=> 'New Image Size',
			'desc'				=> esc_html__('Remember dont change image size default name, after add new or change size please run plugin Regenerate Thumbnails to update new size.', 'amy-movie'),
			'fields' 			=> array(
				array(
					'id' 	=> 'img_size_name',
					'type' 	=> 'text',
					'title' => esc_html__('Size Name', 'amy-movie'),
				),

				array(
					'id' 	=> 'img_size_width',
					'type' 	=> 'number',
					'title' => esc_html__('Width', 'amy-movie'),
				),

				array(
					'id' 	=> 'img_size_height',
					'type' 	=> 'number',
					'title' => esc_html__('Height', 'amy-movie'),
				),

				array(
					'id'	=> 'img_crop',
					'type'	=> 'switcher',
					'title'	=> esc_html__('Crop', 'amy-movie'),
					'default' => '1',
				),

			),
			'default'	=> array(
				array(
					'img_size_name'		=> 'Movie List Size',
					'img_size_width'	=> '205',
					'img_size_height'	=> '347',
					'img_crop'			=> '1',
				),

				array(
					'img_size_name'		=> 'Movie Grid Layout 1',
					'img_size_width'	=> '360',
					'img_size_height'	=> '618',
					'img_crop'			=> '1',
				),

				array(
					'img_size_name'		=> 'Movie Grid Layout 2',
					'img_size_width'	=> '164',
					'img_size_height'	=> '220',
					'img_crop'			=> '1',
				),

				array(
					'img_size_name'		=> 'Movie Grid Layout 3',
					'img_size_width'	=> '360',
					'img_size_height'	=> '618',
					'img_crop'			=> '1',
				),

				array(
					'img_size_name'		=> 'Movie Grid Layout 4',
					'img_size_width'	=> '360',
					'img_size_height'	=> '618',
					'img_crop'			=> '1',
				),

				array(
					'img_size_name'		=> 'Movie Carousel Size',
					'img_size_width'	=> '233',
					'img_size_height'	=> '396',
					'img_crop'			=> '1',
				),
			),
		),
	),
);

// ----------------------------------------------
// Custom CSS/JS
// ----------------------------------------------
$options[] = array(
	'name'		=> 'custom',
	'title'		=> esc_html__('Custom CSS & JS', 'amy-movie'),
	'icon'      => 'fa fa-code',
	'fields'	=> array(
		array(
			'id'		=> 'custom_css',
			'type'		=> 'textarea',
			'title'		=> esc_html__('Custom Css', 'amy-movie'),
		),

		array(
			'id'		=> 'custom_js',
			'type'		=> 'textarea',
			'title'		=> esc_html__('Custom Js', 'amy-movie'),
			'after'		=> esc_html__('Do not include <script></script> tag.', 'amy-movie'),
		),
	),
);


// ----------------------------------------------
// IMPORT CONTENT
// ----------------------------------------------
$condition 	= (function_exists('is_vc_activated') && is_vc_activated() && class_exists('Amy_Movie_Helper') && class_exists('RevSlider'));
$message	= esc_html__('You need to activate plugins Visual Composer, Amy Movie Extends, Slider Revolution before importing content demo', 'amy-movie');

$options[] = array(
	'name'		=> 'democontent',
	'title'		=> esc_html__('Demo Content', 'amy-movie'),
	'icon'		=> 'fa fa-diamond',
	'fields'	=> array(
		array(
			'id'  => 'demo_import',
			'type'  => 'demo_importer',
			'condition' => $condition,
			'message' => $message,
			'demos'  => array(
				array(
					'id'  => 'single-cinema',
					'title'  => esc_html__('Single Cinema', 'amy-movie'),
					'thumbnail' => get_template_directory_uri() . '/images/config/demo/single-cinema.jpg'
				),

				array(
					'id'  => 'multi-cinema',
					'title'  => esc_html__('Multi Cinema', 'amy-movie'),
					'thumbnail' => get_template_directory_uri() . '/images/config/demo/multi-cinema.jpg'
				),

				array(
					'id'  => 'movie-news',
					'title'  => esc_html__('Movie News', 'amy-movie'),
					'thumbnail' => get_template_directory_uri() . '/images/config/demo/movie-news.jpg'
				),

				array(
					'id'  => 'watch-online',
					'title'  => esc_html__('Watch Online', 'amy-movie'),
					'thumbnail' => get_template_directory_uri() . '/images/config/demo/watch-online.jpg'
				),

				array(
					'id'  => 'book-ticket',
					'title'  => esc_html__('Book Ticket', 'amy-movie'),
					'thumbnail' => get_template_directory_uri() . '/images/config/demo/book-ticket.jpg'
				),
			)
		),
	),
);

// ----------------------------------------------
// IMPORT IMDB
// ----------------------------------------------
$options[] = array(
	'name'		=> 'imdbimport',
	'title'		=> esc_html__('IMDB/TMDB Import', 'amy-movie'),
	'icon'      => 'fa fa-exchange',
	'fields'	=> array(
		array(
			'id'		=> 'imdb_heading',
			'type'		=> 'heading',
			'content'	=> esc_html__('API Settings', 'amy-movie')
		),

		array(
			'id'		=> 'api_type',
			'type'		=> 'select',
			'class'		=> 'chosen',
			'title'		=> esc_html__('Api Type', 'amy-movie'),
			'options'	=> array(
				'omdb'		=> esc_html__('Omdbapi', 'amy-movie'),
				'myapi'		=> esc_html__('Myapifilms', 'amy-movie')
			),
		),

		array(
			'id'			=> 'omdb_api_key',
			'type'			=> 'text',
			'title'			=> esc_html__('OMDB key', 'amy-movie'),
			'info'			=> esc_html__('You need get api from http://www.omdbapi.com/apikey.aspx', 'amy-movie'),
			'dependency'	=> array('api_type', '==', 'omdb')
		),

		array(
			'id'			=> 'imdb_api_key',
			'type'			=> 'text',
			'title'			=> esc_html__('MyApi key', 'amy-movie'),
			'info'			=> esc_html__('You need get api from http://www.myapifilms.com/token.do', 'amy-movie'),
			'dependency'	=> array('api_type', '==', 'myapi')
		),

		array(
			'id'		=> 'imdb_timeout',
			'type'		=> 'number',
			'title'		=> esc_html__('Set Timeout', 'amy-movie'),
			'default'	=> '300',
			'info'		=> esc_html__('Set max_execution_time to avoid timeout to import movie.', 'amy-movie')
		)
	),
);

// ----------------------------------------------
// LANGUAGE
// ----------------------------------------------
//$options[] = array(
//	'name'		=> 'language',
//	'title'		=> esc_html__('Language', 'amy-movie'),
//	'icon'      => 'fa fa-language',
//	'fields'	=> array(
//		array(
//			'id'				=> 'lang_pervious_page',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Previous Page', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Previous Page', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_back_to_home',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Back To Home', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Back To Home', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_comments',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Comments', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Comments', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_older_comments',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Older Comments', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Older Comments', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_newer_comments',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Newer Comments', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Newer Comments', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_release',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Release', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Release', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_imdb',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Imdb', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Imdb', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_language',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Language', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Language', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_genre',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Genre', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Genre', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_actor',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Actor', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Actor', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_director',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Director', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Director', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_cinema',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Cinema', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Cinema', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_movie',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Movie', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Movie', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_title',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Title', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Title', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_banner',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Banner', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Banner', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_gallery',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Gallery', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Gallery', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_address',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Address', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Address', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_phone',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Phone', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Phone', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_website',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Website', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Website', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_release_date',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Release Date', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Release Date', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_duration',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Duration', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Duration', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_imdb',
//			'type'				=> 'text',
//			'title'				=> esc_html__('IMDB', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('IMDB', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_mpaa',
//			'type'				=> 'text',
//			'title'				=> esc_html__('MPAA', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('MPAA', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_hello',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Hello', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Hello ', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_logout',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Log Out', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Log Out', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_login',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Login', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Login', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_register',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Register', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Register', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_prev',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Prev', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Prev', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_next',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Next', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Next', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_name',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Name', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Name', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_write_a_comment',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Write a comment', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Write a comment', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_comment',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Comment', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Comment', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_no_movie',
//			'type'				=> 'text',
//			'title'				=> esc_html__('No movie', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('No movie', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_no_time',
//			'type'				=> 'text',
//			'title'				=> esc_html__('No Time', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('No Time', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_you_already_rate_a_movie',
//			'type'				=> 'text',
//			'title'				=> esc_html__('You already rate a movie', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('You already rate a movie', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_you_vote_done',
//			'type'				=> 'text',
//			'title'				=> esc_html__('You vote done', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('You vote done', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_no_director',
//			'type'				=> 'text',
//			'title'				=> esc_html__('No Director', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('No Director', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_no_actor',
//			'type'				=> 'text',
//			'title'				=> esc_html__('No Actor', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('No Actor', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_no_cinema',
//			'type'				=> 'text',
//			'title'				=> esc_html__('No Cinema', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('No Cinema', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_no_movie',
//			'type'				=> 'text',
//			'title'				=> esc_html__('No Movie', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('No Movie', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_turn_off_the_light',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Turn off the light', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Turn off the light', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_turn_on_the_light',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Turn on the light', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Turn on the light', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_movie_info',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Movie Info', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Movie Info', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_address',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Address:', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Address:', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_phone',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Phone:', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Phone:', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_email',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Email:', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Email:', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_website',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Website:', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Website:', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_comments',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Comments', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Comments', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_map',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Map', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Map', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_select_a_cinema',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Select a cinema', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Select a cinema', 'amy-movie'),
//		),
//
//		array(
//			'id'				=> 'lang_synopsis',
//			'type'				=> 'text',
//			'title'				=> esc_html__('Synopsis', 'amy-movie'),
//			'multilang'			=> true,
//			'default'			=> esc_html__('Synopsis', 'amy-movie'),
//		),
//	)
//);
AmyFramework::instance($settings, $options);