<?php
/**
 * @copyright	Copyright (c) 2016 AmyTheme (http://www.amytheme.com). All rights reserved.
 * @license		http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('ABSPATH') or die;

// ===============================================================================================
// -----------------------------------------------------------------------------------------------
// METABOX OPTIONS
// -----------------------------------------------------------------------------------------------
// ===============================================================================================
$options	= array();

$sidebars = array(
	'left'    => get_template_directory_uri() . '/images/sidebars/sidebar_left.png',
	'right'   => get_template_directory_uri() . '/images/sidebars/sidebar_right.png',
	'full'    => get_template_directory_uri() . '/images/sidebars/sidebar_full.png',
	'fluid'   => get_template_directory_uri() . '/images/sidebars/sidebar_fluid.png',
);

global $wp_registered_sidebars;
$sidebar_widgets = array();

if (! empty($wp_registered_sidebars)) {
	foreach ($wp_registered_sidebars as $key => $value) {
		$sidebar_widgets[ $key ] = $value['name'];
	}
}

// -----------------------------------------------------------------------------------------------
// MOVIE DETAILS
// -----------------------------------------------------------------------------------------------
$defaults_fields	= amy_get_option('movie_default_fields', amy_movie_defaults_fields());
$custom_fields		= amy_get_option('movie_custom_fields');
$movie_section		= array();
$movie_field		= array();

//Release
if (in_array('movie_release', $defaults_fields)) {
	$movie_field[] = array(
		'id'    => 'movie_release',
		'type'  => 'datepicker',
		'title' => esc_html__('Release', 'amy-movie'),
	);
}

//Duration
if (in_array('movie_duration', $defaults_fields)) {
	$movie_field[] = array(
		'id'	=> 'movie_duration',
		'type'	=> 'text',
		'title'	=> esc_html__('Duration', 'amy-movie'),
		'after'	=> '<em>min</em>',
	);
}

//Imdb
if (in_array('movie_imdb', $defaults_fields)) {
	$movie_field[] = array(
		'id'	=> 'movie_imdb',
		'type'	=> 'text',
		'title'	=> esc_html__('Imdb rating', 'amy-movie'),
	);
}

//Mpaa
if (in_array('movie_mpaa', $defaults_fields)) {
	$movie_field[] = array(
		'id'	=> 'movie_mpaa',
		'type'	=> 'text',
		'title'	=> esc_html__('MPAA', 'amy-movie'),
	);
}

//Language
if (in_array('movie_language', $defaults_fields)) {
	$movie_field[] = array(
		'id'	=> 'movie_language',
		'type'	=> 'text',
		'title'	=> esc_html__('Language', 'amy-movie'),
	);
}

if (!empty($custom_fields)) {
	foreach ($custom_fields as $field) {
		if ($field['type'] == 'text') {
			$name = (isset($field['name']) && $field['name'] != '') ? $field['name'] : '';

			$movie_field[] = array(
				'id'	=> sanitize_title($name),
				'type'	=> 'text',
				'title'	=> $name,
			);
		}
	}
}

//Media
$movie_media	= array(
	array(
		'id'    => 'movie_gallery',
		'type'  => 'gallery',
		'title' => esc_html__('Gallery', 'amy-movie'),
	),

	array(
		'id'              	=> 'movie_tralier',
		'type'            	=> 'group',
		'button_title'    	=> esc_html__('Add new tralier', 'amy-movie'),
		'accordion_title' 	=> esc_html__('Tralier', 'amy-movie'),
		'title'				=> esc_html__('Tralier', 'amy-movie'),
		'fields'			=> array(
			array(
				'id'		=> 'movie_tralier_link',
				'type'		=> 'text',
				'title'		=> esc_html__('Tralier link', 'amy-movie'),
				'desc'		=> esc_html__('Support youtube or vimeo', 'amy-movie'),
				'info'		=> esc_html__('Youtube link: https://www.youtube.com/watch?v=, Vimeo link: https://vimeo.com/', 'amy-movie'),
			),
		),
	)
);

//Start & End date
$movie_time = array();
$start_date = array();
$end_date	= array();

if (amy_get_option('enable_start_end_date', false)) {
	$start_date = array(
		'id'    => 'movie_start_date',
		'type'  => 'datepicker',
		'title' => esc_html__('Start Date', 'amy-movie'),
	);

	$end_date = array(
		'id'    => 'movie_end_date',
		'type'  => 'datepicker',
		'title' => esc_html__('End Date', 'amy-movie'),
	);

	$movie_time[] = $start_date;
	$movie_time[] = $end_date;
}

//section
$movie_section[] =  array(
	'name'		=> 'movie_details',
	'title'		=> esc_html__('Details', 'amy-movie'),
	'fields'	=> $movie_field
);

$movie_section[] = array(
	'name'		=> 'movie_media',
	'title'		=> esc_html__('Media', 'amy-movie'),
	'fields'	=> $movie_media
);

if (amy_get_option('enable_start_end_date', false)) {
	$movie_section[] = array(
		'name'		=> 'movie_time',
		'title'		=> esc_html__('Start & End Date', 'amy-movie'),
		'fields'	=> $movie_time
	);
}

if (amy_get_option('enable_streaming', false)) {
	$movie_section[] = array(
		'name'		=> 'movie_layout',
		'title'		=> esc_html__('Layout', 'amy-movie'),
		'fields'	=> array(
			array(
				'id'		=> 'movie_layout',
				'type'		=> 'select',
				'class'		=> 'chosen',
				'title'		=> esc_html__('Layout', 'amy-movie'),
				'options'	=> array(
					'normal'	=> esc_html__('Normal', 'amy-movie'),
					'stream'	=> esc_html__('Streaming', 'amy-movie'),
				),
				'default'	=> amy_get_option('single_movie_default_layout', 'stream')
			),
		)
	);
}

$options[] = array(
	'id'		=> '_movie_block_details',
	'title'		=> esc_html__('Movie Details', 'amy-movie'),
	'post_type'	=> array('amy_movie', 'amy_tvshow', 'amy_season'),
	'context'   => 'normal',
	'priority'  => 'default',
	'sections'	=> $movie_section
);

// -----------------------------------------------------------------------------------------------
// MOVIE STREAMING
// -----------------------------------------------------------------------------------------------
if (amy_get_option('enable_streaming', false)) {
	$options[] = array(
		'id'		=> '_movie_streaming',
		'title'		=> esc_html__('Movie Streaming', 'amy-movie'),
		'post_type'	=> 'amy_movie',
		'context'   => 'normal',
		'priority'  => 'default',
		'sections'	=> array(
			array(
				'name' => 'movie_streaming',
				'fields' => array(
					array(
						'id' => 'servers',
						'type' => 'group',
						'button_title' => esc_html__('Add Server', 'amy-movie'),
						'accordion_title' => esc_html__('New Server', 'amy-movie'),
						'fields' => array(
							array(
								'id' => 'title',
								'type' => 'text',
								'title' => esc_html__('Server Title', 'amy-movie'),
							),
							array(
								'id' => 'parts',
								'type' => 'group',
								'title' => esc_html__('Parts', 'amy-movie'),
								'button_title' => esc_html__('Add Part', 'amy-movie'),
								'accordion_title' => esc_html__('New Part', 'amy-movie'),
								'fields' => array(
									array(
										'id' => 'title',
										'type' => 'text',
										'title' => esc_html__('Part Title', 'amy-movie'),
									),
									array(
										'id' => 'link',
										'type' => 'text',
										'title' => esc_html__('Video Link', 'amy-movie'),
									)
								)
							)
						)
					)
				)
			)
		)
	);
}

// -----------------------------------------------------------------------------------------------
// MOVIE CINEMA
// -----------------------------------------------------------------------------------------------
$cinema_opts 	= array();
$cinema_list	= amy_movie_get_cinema();

if (!empty($cinema_list)) {
	foreach ($cinema_list as $cinema) {
		$cinema_opts[ $cinema->ID ] = $cinema->post_title;
	}
}

if (amy_get_option('enable_m_cinema', true) == true) {
	$movie_showtimes = array();

	$movie_showtimes[] = array(
		'id' => 'date',
		'type' => 'datepicker',
		'title' => esc_html__('Date', 'amy-movie'),
	);

	$movie_showtimes[] = array(
		'id' => 'hour',
		'type' => 'text',
		'class' => 'amy-tagsinput',
		'title' => esc_html__('Time', 'amy-movie'),
		'after' => esc_html__('List hour in date. Eg: 12h30, 20h24', 'amy-movie'),
	);

	if (amy_get_option('enable_m_ticket', false) == true && class_exists('woocommerce') && defined('SMARTCMS_SRW_URL')) {
		$product_args 	= array('post_type' => 'product', 'posts_per_page' => -1);
		$products 		= get_posts($product_args);
		$product_arr	= array();

		if (!empty($products)) {
			foreach ($products as $p) {
				$product_arr[$p->ID] = $p->post_title;
			}
		}

		if (!empty($product_arr)) {
			$movie_showtimes[] = array(
				'title'		=> esc_html__('Product ticket', 'amy-movie'),
				'id'		=> 'link_product_buyticket',
				'type'		=> 'select',
				'options'	=> $product_arr,
				'class'		=> 'chosen'
			);
		}
	} else {
		$movie_showtimes[] = array(
			'id'	=> 'link_buyticket',
			'type'	=> 'text',
			'title'	=> esc_html__('Link Buy Ticket', 'amy-movie')
		);
	}


	if (amy_get_option('is_single_cinema', false) == true) {
		$options[] = array(
			'id' => '_movie_block_showtime',
			'title' => esc_html__('Showtime Events', 'amy-movie'),
			'post_type' => 'amy_movie',
			'context' => 'normal',
			'priority' => 'default',
			'sections' => array(
				array(
					'name' => 'movie_cinema',
					'fields' => array(
						array(
							'id'				=> 'movie_showtimes',
							'type'				=> 'group',
							'button_title'		=> esc_html__('Add new Showtime', 'amy-movie'),
							'accordion_title'	=> esc_html__('Showtime', 'amy-movie'),
							'fields'			=> $movie_showtimes
						),
					),
				),
			),
		);
	} else {
		$options[] = array(
			'id' => '_movie_block_cinema',
			'title' => esc_html__('Cinema Events', 'amy-movie'),
			'post_type' => 'amy_movie',
			'context' => 'normal',
			'priority' => 'default',
			'sections' => array(
				array(
					'name' => 'movie_cinema',
					'fields' => array(
						array(
							'id' 				=> 'amy_movie_cinema',
							'type' 				=> 'group',
							'button_title' 		=> esc_html__('Add new Cinema', 'amy-movie'),
							'accordion_title' 	=> esc_html__('Cinema', 'amy-movie'),
							'fields' => array(
								array(
									'id' 		=> 'select_cinema',
									'type' 		=> 'select',
									'class'		=> 'chosen',
									'title' 	=> esc_html__('Cinema', 'amy-movie'),
									'options' 	=> $cinema_opts,
								),

								array(
									'id'				=> 'movie_showtimes',
									'type'				=> 'group',
									'button_title'		=> esc_html__('Add new Showtime', 'amy-movie'),
									'accordion_title'	=> esc_html__('Showtime', 'amy-movie'),
									'fields'			=> $movie_showtimes
								),
							),
						),
					),
				),
			),
		);
	}

}

// -----------------------------------------------------------------------------------------------
// MOVIE RATE
// -----------------------------------------------------------------------------------------------
$m_turn 	= 0;
$m_point 	= 0;
$m_ave 		= 0;

if (isset($_GET['post'])) {
	$postid 	= $_GET['post'];
	$m_rate		= amy_movie_get_rating($postid);

	if (isset($m_rate['movie_rating_turn'])) {
		$m_turn = $m_rate['movie_rating_turn'];
	}

	if (isset($m_rate['movie_rating_points'])) {
		$m_point = $m_rate['movie_rating_points'];
	}
	if ($m_point != 0 && $m_turn != 0) {
		$m_ave	= round($m_point / $m_turn, 1);
	}
}

$rate_note = 'Now: ' . $m_turn . ' turn rate, ' . $m_point . ' total points, average: ' . $m_ave . '';

$options[] = array(
	'id'		=> '_movie_block_rating',
	'title'		=> esc_html__('Movie Rating', 'amy-movie'),
	'post_type'	=> array('amy_movie', 'amy_tvshow'),
	'context'	=> 'normal',
	'priority'  => 'default',
	'sections'	=> array(
		array(
			'name'		=> 'movie_rating',
			'fields'	=> array(
			    array(
					'type'    => 'notice',
					'class'   => 'success',
					'content' => $rate_note,
				),

				array(
					'id'		=> 'custom_rating',
					'type'		=> 'switcher',
					'default'	=> false,
					'title'		=> esc_html__('Custom rating', 'amy-movie'),
				),

				array(
					'id'			=> 'movie_rating_turn',
					'type'			=> 'text',
					'title'			=> esc_html__('Turn rating', 'amy-movie'),
					'dependency'	=> array('custom_rating', '==', true),
					'default'		=> $m_turn,
				),

				array(
					'id'			=> 'movie_rating_points',
					'type'			=> 'text',
					'title'			=> esc_html__('Total Points', 'amy-movie'),
					'dependency'	=> array('custom_rating', '==', true),
					'default'		=> $m_point,
				),
			),
		),
	),
);

// -----------------------------------------------------------------------------------------------
// MOVIE SIDEBAR
// -----------------------------------------------------------------------------------------------
$options[]  = array(
	'id'        => '_movie_banner',
	'title'     => esc_html__('Movie Banner', 'amy-movie'),
	'post_type' => array('amy_movie', 'amy_tvshow', 'amy_season'),
	'context'   => 'side',
	'priority'  => 'low',
	'sections'  => array(
		array(
			'name'			=> '_movie_banner',
			'fields'      	=> array(
				array(
					'id'		=> 'movie_banner',
					'type'      => 'image',
				),
			),
		),

	),
);

$options[]  = array(
	'id'        => '_movie_poster',
	'title'     => esc_html__('Movie Poster', 'amy-movie'),
	'post_type' => array('amy_movie', 'amy_tvshow', 'amy_season'),
	'context'   => 'side',
	'priority'  => 'low',
	'sections'  => array(
		array(
			'name'			=> '_movie_poster',
			'fields'      => array(
				array(
					'id'        => 'movie_poster',
					'type'      => 'image',
				),
			),
		),

	),
);

$options[]  = array(
	'id'        => '_movie_sidebar',
	'title'     => esc_html__('Movie Sidebar', 'amy-movie'),
	'post_type' => array('amy_movie', 'amy_tvshow', 'amy_season'),
	'context'   => 'side',
	'priority'  => 'low',
	'sections'  => array(
		array(
			'title'       => esc_html__('Movie Sidebar', 'amy-movie'),
			'name'			=> '_movie_sidebar',
			'fields'      => array(
				array(
					'id'          => 'movie_sidebar',
					'type'        => 'image_select',
					'radio'       => true,
					'options'     => array(
						'left'    => get_template_directory_uri() . '/images/sidebars/sidebar_left.png',
						'right'   => get_template_directory_uri() . '/images/sidebars/sidebar_right.png',
						'full'    => get_template_directory_uri() . '/images/sidebars/sidebar_full.png',
					),
					'default'     => amy_get_option('movie_sidebar_default', 'right'),
					'attributes'	=> array(
						'data-depend-id'	=> '_movie_sidebar',
					),
				),

				array(
					'id'              => 'movie_sidebar_widget',
					'type'            => 'select',
					'options'         => array_reverse($sidebar_widgets),
					'default_option'  => amy_get_option('movie_widget_default', 'rightbar'),
					'dependency'      => array('_movie_sidebar', 'any', 'right,left'),
					'class'				=> 'chosen'
				),
			),
		),

	),
);
// -----------------------------------------------------------------------------------------------
// CINEMA OPTIONS
// -----------------------------------------------------------------------------------------------
$options[] = array(
	'id'		=> '_cinema_block_options',
	'title'		=> esc_html__('Cinema Details', 'amy-movie'),
	'post_type'	=> 'amy_cinema',
	'context'   => 'normal',
	'priority'  => 'default',
	'sections'	=> array(
		array(
			'name'			=> 'cinema_details',
			'fields'      => array(
				array(
					'id'    => 'cinema_banner',
					'type'  => 'image',
					'title' => esc_html__('Banner', 'amy-movie'),
				),

				array(
					'id'    => 'cinema_gallery',
					'type'  => 'gallery',
					'title' => esc_html__('Gallery', 'amy-movie'),
				),

				array(
					'id'    => 'cinema_address',
					'type'  => 'text',
					'title' => esc_html__('Address', 'amy-movie'),
				),

				array(
					'id'    => 'cinema_phone',
					'type'  => 'text',
					'title' => esc_html__('Phone', 'amy-movie'),
				),

				array(
					'id'    => 'cinema_website',
					'type'  => 'text',
					'title' => esc_html__('Website', 'amy-movie'),
				),

				array(
					'id'    => 'cinema_email',
					'type'  => 'text',
					'title' => esc_html__('Email', 'amy-movie'),
				),

				array(
					'id'    	=> 'cinema_map',
					'type'  	=> 'textarea',
					'title' 	=> esc_html__('Google Map Iframe', 'amy-movie'),
					'sanitize' 	=> true,
					'after'		=> esc_html__('Visit Google maps to create your map (Step by step: 1) Find location 2) Click the cog symbol in the lower right corner and select "Share or embed map" 3) On modal window select "Embed map" 4) Copy iframe code and paste it).', 'amy-movie'),
				),
			),
		),
	),
);


// -----------------------------------------------------------------------------------------------
// PAGE OPTIONS
// -----------------------------------------------------------------------------------------------
$options[]  = array(
	'id'        => '_sidebar',
	'title'     => esc_html__('Page Sidebar Model', 'amy-movie'),
	'post_type' => 'page',
	'context'   => 'side',
	'priority'  => 'low',
	'sections'  => array(
		array(
			'name'			=> '_page_sidebar',
			'title'       => esc_html__('Page Sidebar', 'amy-movie'),
			'fields'      => array(
				array(
					'id'          => 'page_sidebar',
					'type'        => 'image_select',
					'radio'       => true,
					'options'     => $sidebars,
					'default'     => array('full'),
					'attributes'  => array(
						'data-depend-id'  => 'page_sidebars',
					),
				),

				array(
					'id'              => 'page_sidebar_widget',
					'type'            => 'select',
					'options'         => array_reverse($sidebar_widgets),
					'default_option'	=> esc_html__('Choose a custom sidebar', 'amy-movie'),
					'dependency'		=> array('page_sidebars', 'any', 'right,left'),
				),
			),
		),

	),
);

$options[] = array(
	'id'			=> '_custom_page_options',
	'title'			=> esc_html__('Page Options', 'amy-movie'),
	'post_type'		=> 'page',
	'context'		=> 'normal',
	'priority'		=> 'default',
	'sections'		=> array(
		array(
			'name'		=> 'page_options',
			'fields'	=> array(
				array(
					'id'		=> 'enable_page_title',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Enable Page Title', 'amy-movie'),
					'default'	=> true,
				),

				array(
					'id'		=> 'title_position',
					'type'		=> 'select',
					'title'		=> esc_html__('Title Position', 'amy-movie'),
					'options'	=> array(
						'center'	=> esc_html__('Center', 'amy-movie'),
						'left'		=> esc_html__('Left', 'amy-movie'),
						'right'		=> esc_html__('Right', 'amy-movie'),
					),
					'default'	=> 'left',
					'dependency'	=> array('enable_page_title', '==', true),
				),

				array(
					'id'		=> 'title_background_image',
					'type'		=> 'image',
					'title'		=> esc_html__('Title Background Image', 'amy-movie'),
					'dependency'	=> array('enable_page_title', '==', true),
				),

				array(
					'id'		=> 'title_background',
					'type'		=> 'color_picker',
					'title'		=> esc_html__('Title Background', 'amy-movie'),
					'dependency'	=> array('enable_page_title', '==', true),
				),

				array(
					'id'		=> 'tile_color',
					'type'		=> 'color_picker',
					'title'		=> esc_html__('Title Color', 'amy-movie'),
					'dependency'	=> array('enable_page_title', '==', true),
				),
			),
		),
	),
);

// -----------------------------------------------------------------------------------------------
// TVSHOW OPTIONS
// -----------------------------------------------------------------------------------------------
$tvshow_fields	= array();
$season_opts 	= array();
$list_season	= amy_movie_get_list_season();

if (!empty($list_season)) {
	foreach ($list_season as $l) {
		$season_opts[$l->ID] = $l->post_title;
	}
}

$season_in_tvshow = array(
	'id'				=> 'season_list',
	'type'				=> 'group',
	'title'				=> esc_html__('Season', 'amy-movie'),
	'button_title'		=> esc_html__('Add New Season', 'amy-movie'),
	'accordion'			=> true,
	'accordion_title'	=> esc_html__('New Season', 'amy-movie'),
	'fields'			=> array(
		array(
			'id' => 'select_season',
			'type' => 'select',
			'class'	=> 'chosen',
			'title' => esc_html__('Season', 'amy-movie'),
			'options' => $season_opts,
		),
	),
);

$tvshow_fields[] = $season_in_tvshow;

$options[]	= array(
	'id'		=> '_tvshow_details',
	'title'		=> esc_html__('Season List', 'amy-movie'),
	'post_type'	=> array('amy_tvshow'),
	'context'	=> 'normal',
	'priority'	=> 'low',
	'sections'	=> array(
		array(
			'name'			=> 'tvshow_detail',
			'fields'		=> $tvshow_fields
		),
	),
);

// -----------------------------------------------------------------------------------------------
// TVSHOW SEASON
// -----------------------------------------------------------------------------------------------
$tvshow_opts 	= array();
$tvshow_list	= amy_movie_get_list_tvshow();

if (!empty($tvshow_list)) {
	foreach ($tvshow_list as $m) {
		$tvshow_opts[$m->ID] = $m->post_title;
	}
}

$list_episodes_params = array();

$list_episodes_params[] = array(
	'id'			=> 'title',
	'type'			=> 'text',
	'title'			=> esc_html__('Title', 'amy-movie'),
);

if (amy_get_option('enable_streaming', false)) {
	$list_episodes_params[] = array(
		'id'				=> 'list_server',
		'type'				=> 'group',
		'title'				=> esc_html__('List Server', 'amy-movie'),
		'button_title'		=> esc_html__('Add New Server', 'amy-movie'),
		'accordion'			=> true,
		'accordion_title'	=> esc_html__('New Server', 'amy-movie'),
		'fields'			=> array(
			array(
				'id'			=> 'title',
				'type'			=> 'text',
				'title'			=> esc_html__('Server Title', 'amy-movie'),
			),

			array(
				'id'			=> 'link',
				'type'			=> 'text',
				'title'			=> esc_html__('Server Link', 'amy-movie'),
			)
		),
	);
}

$options[]	= array(
	'id'		=> '_season_details',
	'title'		=> esc_html__('Season Details', 'amy-movie'),
	'post_type'	=> array('amy_season'),
	'context'	=> 'normal',
	'priority'	=> 'low',
	'sections'	=> array(
		array(
			'name'			=> 'season_detail',
			'fields'		=> array(
				array(
					'id' => 'select_tvshow',
					'type' => 'select',
					'class'	=> 'chosen',
					'title' => esc_html__('Select Tvshow', 'amy-movie'),
					'options' => $tvshow_opts,
				),

				array(
					'id'				=> 'list_episodes',
					'type'				=> 'group',
					'title'				=> esc_html__('List Episodes', 'amy-movie'),
					'button_title'		=> esc_html__('Add New Episode', 'amy-movie'),
					'accordion'			=> true,
					'accordion_title'	=> esc_html__('New Episode', 'amy-movie'),
					'fields'			=> $list_episodes_params,
				),
			)
		),
	),
);

AmyFramework_Metabox::instance($options);
